@@ -73,6 +73,7 @@ dlcompare <- structure(function # Direct label comparison plot
   library(lattice)
   library(ggplot2)
   oldopt <- lattice.options(panel.error=NULL)
+
   dts <- cbind(male=mdeaths,female=fdeaths,time=1:length(mdeaths))
   ddf <- melt(as.data.frame(dts),id="time")
   names(ddf) <- c("time","sex","deaths")
@@ -80,12 +81,6 @@ dlcompare <- structure(function # Direct label comparison plot
                 xyplot(deaths~time,ddf,groups=sex,type="l",xlim=c(-15,80)),
                 ggplot2=
                 qplot(time,deaths,data=ddf,colour=sex,geom="line")+xlim(-10,80))
-  pos.funs <- list("first.points","lines2")
-  ##pdf("compare.pdf",width=10,height=10)
-  dlcompare(plots,pos.funs)
-  dlcompare(plots,pos.funs,rects=FALSE) ## hide the grid
-  dlcompare(plots,pos.funs,rects=FALSE,row.items="posfuns") ## exchange axes
-  ##dev.off();system("xpdf compare.pdf")
 
   if(names(dev.cur())!="postscript"){##to avoid error on pkg check
     ## Try some more exotic labeling options.
@@ -98,6 +93,13 @@ dlcompare <- structure(function # Direct label comparison plot
     dlcompare(plots,list(exotic))
   }
   
+  pos.funs <- list("first.points","lines2")
+  ##pdf("compare.pdf",width=10,height=10)
+  dlcompare(plots,pos.funs)
+  dlcompare(plots,pos.funs,rects=FALSE) ## hide the grid
+  dlcompare(plots,pos.funs,rects=FALSE,row.items="posfuns") ## exchange axes
+  ##dev.off();system("xpdf compare.pdf")
+
   ## All of these subsets should produce valid comparison plots.
   dlcompare(plots[1],pos.funs[1])
   dlcompare(plots[1],pos.funs)
@@ -110,8 +112,14 @@ dlcompare <- structure(function # Direct label comparison plot
   dlcompare(plots,mixed.funs[3])
 
   data(BodyWeight,package="nlme")
-  ratplot <- xyplot(weight~Time|Diet,BodyWeight,groups=Rat,type="l",layout=c(3,1))
-
+  ratplot <- xyplot(weight~Time|Diet,BodyWeight,
+                    groups=Rat,type="l",layout=c(3,1))
+  ##   ggrat <- qplot(Time,weight,data=BodyWeight,
+  ##                  colour=Rat,geom="line",facets=.~Diet)
+  ##   png("~/R/directlabels/www/rat-ggplot2-firstlast.png",h=400,w=900)
+  ##   dlcompare(list(ggrat+ylim(130,max(BodyWeight$weight))),
+  ##             list("first.qp","last.qp"),row.items="pfs",rects=FALSE)
+  ##   dev.off()
   ## Compare scatterplot labeling methods.
   scatters <-
     list(xyplot(jitter(cty)~jitter(hwy),mpg,groups=class,aspect=1),
