@@ -70,7 +70,7 @@ dldoc <- function # Make directlabels documentation
   for(i in 1:nrow(m))if(length(m[i,]$plots))for(j in seq_along(m[i,]$plots)){
     m[i,]$plots[[j]]$code <- rhtmlescape(m[i,]$plots[[j]]$code)
   }
-
+  theme_set(theme_grey())
   setwd(file.path("..","..","www","docs"))
   foot <- paste(readLines("templates/foot.html"),collapse="\n")
   makehtml <- function # Make HTML documentation
@@ -96,7 +96,13 @@ dldoc <- function # Make directlabels documentation
         if(!file.exists(pngfile)){
           cat(" ",f$name,sep="")
           png(pngfile)
-          print(direct.label(p$plot,f$fun))
+          set.seed(1)
+          tryCatch({
+            print(direct.label(p$plot,f$fun))
+          },error=function(e){
+            l <- capture.output(print(e$call))
+            grid.text(sprintf("ERROR\n%s\n%s",l,e$message))
+          })
           dev.off()
         }
         thumbfile <- file.path(subdir,paste(p$name,f$name,"thumb.png",sep="."))
